netapp_ontap.models.aggregate_spare API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.aggregate_spare`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AggregateSpareSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AggregateSpare object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `checksum_style GET`

    The checksum type that has been assigned to the spares

    Valid choices:

    - block
    - advanced_zoned
  `disk_class GET`

    Disk class of spares

    Valid choices:

    - unknown
    - capacity
    - performance
    - archive
    - solid_state
    - array
    - virtual
    - data_center
    - capacity_flash
  `layout_requirements GET POST PATCH`

    Available RAID protections and their restrictions

  `node GET POST PATCH`

    The node field of the aggregate_spare.

  `size GET`

    Usable size of each spare in bytes

    Example: 10156769280

  `syncmirror_pool GET`

    SyncMirror spare pool

    Valid choices:

    - pool0
    - pool1
  `usable GET`

    Total number of usable spares in the bucket. The usable count for each class of spares does not include reserved spare capacity recommended by ONTAP best practices.

    Example: 9